@@ -54,19 +54,20 @@ static void refresh_screen(void)
 
 static void help(void)
 {
-	struct ts_lib_version_data *ver = ts_libversion();
-
-	print_ascii_logo();
-
-	printf("tslib %s / libts ABI version %d (0x%06X)\n",
-		ver->package_version, ver->version_num >> 16, ver->version_num);
+	ts_print_ascii_logo(16);
+	print_version();
 	printf("\n");
-	printf("Usage: ts_test [-r <rotate_value>]\n");
+	printf("Usage: ts_test [-r <rotate_value>] [--version] [--help]\n");
 	printf("\n");
+	printf("-r --rotate\n");
 	printf("        <rotate_value> 0 ... no rotation; 0 degree (default)\n");
 	printf("                       1 ... clockwise orientation; 90 degrees\n");
 	printf("                       2 ... upside down orientation; 180 degrees\n");
 	printf("                       3 ... counterclockwise orientation; 270 degrees\n");
+	printf("-h --help\n");
+	printf("                       print this help test\n");
+	printf("-v --version\n");
+	printf("                       print version information only\n");
 	printf("\n");
 	printf("Example (Linux): ts_test -r $(cat /sys/class/graphics/fbcon/rotate)\n");
 	printf("\n");
@@ -88,10 +89,11 @@ int main(int argc, char **argv)
 		const struct option long_options[] = {
 			{ "help",         no_argument,       NULL, 'h' },
 			{ "rotate",       required_argument, NULL, 'r' },
+			{ "version",      no_argument,       NULL, 'v' },
 		};
 
 		int option_index = 0;
-		int c = getopt_long(argc, argv, "hr:", long_options, &option_index);
+		int c = getopt_long(argc, argv, "hvr:", long_options, &option_index);
 
 		errno = 0;
 		if (c == -1)
@@ -102,6 +104,10 @@ int main(int argc, char **argv)
 			help();
 			return 0;
 
+		case 'v':
+			print_version();
+			return 0;
+
 		case 'r':
 			/* extern in fbutils.h */
 			rotation = atoi(optarg);
