@@ -107,6 +107,10 @@ static void help(void)
 	printf("                       1 ... clockwise orientation; 90 degrees\n");
 	printf("                       2 ... upside down orientation; 180 degrees\n");
 	printf("                       3 ... counterclockwise orientation; 270 degrees\n");
+	printf("-n --samples\n");
+	printf("                       exit automatically after n samples\n");
+	printf("-a --altcross\n");
+	printf("                       use an alternative crosshair\n");
 	printf("-h --help\n");
 	printf("                       print this help text\n");
 	printf("-v --verbose\n");
@@ -148,6 +152,8 @@ int main(int argc, char **argv)
 
 	const char *tsdevice = NULL;
 	char slot_info[64];
+	uint32_t samples = 0;
+	uint32_t have_samples = 0;
 
 	signal(SIGSEGV, sig);
 	signal(SIGINT, sig);
@@ -160,10 +166,12 @@ int main(int argc, char **argv)
 			{ "idev",         required_argument, NULL, 'i' },
 			{ "slots",        required_argument, NULL, 'j' },
 			{ "rotate",       required_argument, NULL, 'r' },
+			{ "samples",      required_argument, NULL, 'n' },
+			{ "altcross",     required_argument, NULL, 'a' },
 		};
 
 		int option_index = 0;
-		int c = getopt_long(argc, argv, "hi:vj:r:", long_options, &option_index);
+		int c = getopt_long(argc, argv, "hi:vj:r:n:a:", long_options, &option_index);
 
 		errno = 0;
 		if (c == -1)
@@ -190,6 +198,18 @@ int main(int argc, char **argv)
 			}
 			break;
 
+		case 'n':
+			samples = atoi(optarg);
+			break;
+
+		case 'a':
+			alternative_cross = atoi(optarg);
+			if (alternative_cross < 0 || alternative_cross > 1) {
+				help();
+				return 0;
+			}
+			break;
+
 		case 'r':
 			/* extern in fbutils.h */
 			rotation = atoi(optarg);
@@ -290,6 +310,13 @@ int main(int argc, char **argv)
 	while (1) {
 		int ret;
 
+		if (samples) {
+			if (samples >= have_samples)
+				goto out;
+
+			have_samples++;
+		}
+
 		/* Show the cross */
 		for (j = 0; j < max_slots; j++) {
 			if ((mode & 15) != 1) { /* not in draw mode */
